import React from "react";
import Button from "@material-ui/core/Button";
import Dialog from "@material-ui/core/Dialog";
import HighlightOffOutlined from "@material-ui/icons/HighlightOffOutlined";
import CheckCircleOutline from "@material-ui/icons/CheckCircleOutline";
import IconButton from "@material-ui/core/IconButton";
import DialogActions from "@material-ui/core/DialogActions";
import Tooltip from "@material-ui/core/Tooltip";
import DialogTitle from "@material-ui/core/DialogTitle";
import { useTheme } from "@material-ui/core/styles";

import { makeStyles } from "@material-ui/core/styles";
const useStyles = makeStyles((theme) => ({
  buttonDeactivate: {
    color: "red",
  },
  buttonReactivate: {
    color: "green",
  },
  buttonYes: {
    color: "blue",
  },
}));

function DeleteButton(props) {
  const classes = useStyles();
  const [open, setOpen] = React.useState(false);
  const theme = useTheme();

  const handleClickOpen = () => {
    setOpen(true);
  };

  const handleCloseFalse = () => {
    setOpen(false);
    props.handleDeactivate(false);
  };

  const handleCloseTrue = () => {
    setOpen(false);
    props.handleDeactivate(true);
  };

  const handleClose = () => {
    setOpen(false);
  };

  return (
    <>
      <Tooltip title={props.status ? "Desativar" : "Reativar"} arrow>
        <IconButton aria-label="delete" onClick={handleClickOpen}>
          {props.status ? <HighlightOffOutlined /> : <CheckCircleOutline />}
        </IconButton>
      </Tooltip>
      <Dialog
        open={open}
        onClose={handleClose}
        aria-labelledby="responsive-dialog-title"
      >
        <DialogTitle id="responsive-dialog-title">
          {props.status
            ? "Tem certeza que deseja desativar este formulário?"
            : "Tem certeza que deseja reativar este formulário?"}
        </DialogTitle>
        <DialogActions>
          <Button
            autoFocus
            onClick={handleCloseFalse}
            className={classes.buttonYes}
            color="primary"
          >
            Não {props.status ? "Desativar" : "Reativar"}
          </Button>
          <Button
            onClick={handleCloseTrue}
            className={
              props.status ? classes.buttonDeactivate : classes.buttonReactivate
            }
            autoFocus
          >
            {props.status ? "Desativar" : "Reativar"}
          </Button>
        </DialogActions>
      </Dialog>
    </>
  );
}

export default DeleteButton;
